pub enum ToolRegistryError {
UnknownTool,
DuplicateTool,
VersionConflict,
HostedToolNameMismatch,
NoSupportedToolRoute {
tool: ToolName,
model: ModelId,
},
HostedToolNotClientExecutable,
ModelProjection(ModelRequestError),
Schema(SchemaCompilationError),
InvalidArguments(SchemaValidationFailure),
Resources(ToolResourceError),
}Expand description
Registry validation, conflict, or resource failure.
Variants
UnknownTool
No active tool has this name.
DuplicateTool
Same name/version is already registered.
VersionConflict
Same name has another active version.
HostedToolNameMismatch
A hosted binding does not use its kind’s stable tool name.
NoSupportedToolRoute
The selected model supports neither the hosted nor client route.
Fields
HostedToolNotClientExecutable
A provider-hosted-only tool was sent to the client execution boundary.
ModelProjection(ModelRequestError)
A projected model definition violates model request bounds.
Schema(SchemaCompilationError)
Input/output schema cannot compile.
InvalidArguments(SchemaValidationFailure)
Arguments violate the registered input schema.
Resources(ToolResourceError)
Resource resolution failed.